Module: Sorcery::Model::ClassMethods
- Defined in:
- lib/sorcery/model.rb
Instance Method Summary collapse
-
#authenticate(*credentials) ⇒ Object
The default authentication method.
-
#encrypt(*tokens) ⇒ Object
encrypt tokens using current encryption_provider.
-
#sorcery_config ⇒ Object
Returns the class instance variable for configuration, when called by the class itself.
Instance Method Details
#authenticate(*credentials) ⇒ Object
The default authentication method. Takes a username and password, Finds the user by the username and compares the user’s password to the one supplied to the method. returns the user if success, nil otherwise.
88 89 90 91 92 93 |
# File 'lib/sorcery/model.rb', line 88 def authenticate(*credentials) raise ArgumentError, "at least 2 arguments required" if credentials.size < 2 user = find_by_credentials(credentials) _salt = user.send(@sorcery_config.salt_attribute_name) if user && !@sorcery_config.salt_attribute_name.nil? && !@sorcery_config.encryption_provider.nil? user if user && @sorcery_config.before_authenticate.all? {|c| user.send(c)} && credentials_match?(user.send(@sorcery_config.crypted_password_attribute_name),credentials[1],_salt) end |
#encrypt(*tokens) ⇒ Object
encrypt tokens using current encryption_provider.
96 97 98 99 100 101 102 103 |
# File 'lib/sorcery/model.rb', line 96 def encrypt(*tokens) return tokens.first if @sorcery_config.encryption_provider.nil? @sorcery_config.encryption_provider.stretches = @sorcery_config.stretches if @sorcery_config.encryption_provider.respond_to?(:stretches) && @sorcery_config.stretches @sorcery_config.encryption_provider.join_token = @sorcery_config.salt_join_token if @sorcery_config.encryption_provider.respond_to?(:join_token) && @sorcery_config.salt_join_token CryptoProviders::AES256.key = @sorcery_config.encryption_key @sorcery_config.encryption_provider.encrypt(*tokens) end |
#sorcery_config ⇒ Object
Returns the class instance variable for configuration, when called by the class itself.
80 81 82 |
# File 'lib/sorcery/model.rb', line 80 def sorcery_config @sorcery_config end |